You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@ignite.apache.org by sb...@apache.org on 2014/12/11 14:13:56 UTC

[19/51] [partial] incubator-ignite git commit: Rename GridException to IgniteCheckedException, GridRuntimeException to IgniteException.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/util/GridReflectionCache.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/util/GridSpiCloseableIteratorWrapper.java b/modules/core/src/main/java/org/gridgain/grid/util/GridSpiCloseableIteratorWrapper.java
index c90f599..b4f0bb6 100644
--- a/modules/core/src/main/java/org/gridgain/grid/util/GridSpiCloseableIteratorWrapper.java
+++ b/modules/core/src/main/java/org/gridgain/grid/util/GridSpiCloseableIteratorWrapper.java
@@ -9,8 +9,8 @@
 
 package org.gridgain.grid.util;
 
+import org.apache.ignite.*;
 import org.apache.ignite.spi.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.util.lang.*;
 
 /**
@@ -33,17 +33,17 @@ public class GridSpiCloseableIteratorWrapper<T> extends GridCloseableIteratorAda
     }
 
     /** {@inheritDoc} */
-    @Override protected T onNext() throws GridException {
+    @Override protected T onNext() throws IgniteCheckedException {
         return iter.next();
     }
 
     /** {@inheritDoc} */
-    @Override protected boolean onHasNext() throws GridException {
+    @Override protected boolean onHasNext() throws IgniteCheckedException {
         return iter.hasNext();
     }
 
     /** {@inheritDoc} */
-    @Override protected void onClose() throws GridException {
+    @Override protected void onClose() throws IgniteCheckedException {
         iter.close();
     }
 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/util/GridUtils.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/util/GridUtils.java b/modules/core/src/main/java/org/gridgain/grid/util/GridUtils.java
index bdc4c3e..803badd 100644
--- a/modules/core/src/main/java/org/gridgain/grid/util/GridUtils.java
+++ b/modules/core/src/main/java/org/gridgain/grid/util/GridUtils.java
@@ -450,7 +450,7 @@ public abstract class GridUtils {
                         ", name2=" + field.getName() + ']';
                 }
                 catch (IllegalAccessException e) {
-                    throw new GridRuntimeException(e);
+                    throw new IgniteException(e);
                 }
             }
         }
@@ -494,7 +494,7 @@ public abstract class GridUtils {
                 assert !containsIntArray(EVTS_ALL_MINUS_METRIC_UPDATE, EVT_NODE_METRICS_UPDATED);
             }
             catch (NoSuchFieldException e) {
-                throw new GridRuntimeException(e);
+                throw new IgniteException(e);
             }
         }
 
@@ -940,9 +940,9 @@ public abstract class GridUtils {
      *
      * @param cls Class to get empty constructor for.
      * @return Empty constructor if one could be found or {@code null} otherwise.
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
-    @Nullable public static Constructor<?> forceEmptyConstructor(Class<?> cls) throws GridException {
+    @Nullable public static Constructor<?> forceEmptyConstructor(Class<?> cls) throws IgniteCheckedException {
         Constructor<?> ctor = null;
 
         try {
@@ -957,7 +957,7 @@ public abstract class GridUtils {
                     ctor = (Constructor)ctorFac.invoke(sunRefFac, cls, U.objectConstructor());
                 }
                 catch (IllegalAccessException | InvocationTargetException e) {
-                    throw new GridException("Failed to get object constructor for class: " + cls, e);
+                    throw new IgniteCheckedException("Failed to get object constructor for class: " + cls, e);
                 }
         }
 
@@ -969,16 +969,16 @@ public abstract class GridUtils {
      *
      * @param cls Class name.
      * @return Instance.
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
-    @Nullable public static <T> T newInstance(String cls) throws GridException {
+    @Nullable public static <T> T newInstance(String cls) throws IgniteCheckedException {
         Class<?> cls0;
 
         try {
             cls0 = Class.forName(cls);
         }
         catch (Exception e) {
-            throw new GridException(e);
+            throw new IgniteCheckedException(e);
         }
 
         return (T)newInstance(cls0);
@@ -989,9 +989,9 @@ public abstract class GridUtils {
      *
      * @param cls Class to instantiate.
      * @return New instance of the class or {@code null} if empty constructor could not be assigned.
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
-    @Nullable public static <T> T newInstance(Class<T> cls) throws GridException {
+    @Nullable public static <T> T newInstance(Class<T> cls) throws IgniteCheckedException {
         boolean set = false;
 
         Constructor<T> ctor = null;
@@ -1011,10 +1011,10 @@ public abstract class GridUtils {
             return ctor.newInstance();
         }
         catch (NoSuchMethodException e) {
-            throw new GridException("Failed to find empty constructor for class: " + cls, e);
+            throw new IgniteCheckedException("Failed to find empty constructor for class: " + cls, e);
         }
         catch (InstantiationException | InvocationTargetException | IllegalAccessException e) {
-            throw new GridException("Failed to create new instance for class: " + cls, e);
+            throw new IgniteCheckedException("Failed to create new instance for class: " + cls, e);
         } finally {
             if (ctor != null && set)
                 ctor.setAccessible(false);
@@ -1026,10 +1026,10 @@ public abstract class GridUtils {
      *
      * @param cls Class to instantiate.
      * @return New instance of the class or {@code null} if empty constructor could not be assigned.
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
     @SuppressWarnings({"unchecked"})
-    @Nullable public static <T> T forceNewInstance(Class<?> cls) throws GridException {
+    @Nullable public static <T> T forceNewInstance(Class<?> cls) throws IgniteCheckedException {
         Constructor ctor = forceEmptyConstructor(cls);
 
         if (ctor == null)
@@ -1048,7 +1048,7 @@ public abstract class GridUtils {
             return (T)ctor.newInstance();
         }
         catch (InstantiationException | InvocationTargetException | IllegalAccessException e) {
-            throw new GridException("Failed to create new instance for class: " + cls, e);
+            throw new IgniteCheckedException("Failed to create new instance for class: " + cls, e);
         } finally {
             if (set)
                 ctor.setAccessible(false);
@@ -1433,10 +1433,10 @@ public abstract class GridUtils {
      * @param locAddr Local address to resolve.
      * @return Resolved available addresses of given local address.
      * @throws IOException If failed.
-     * @throws GridException If no network interfaces found.
+     * @throws IgniteCheckedException If no network interfaces found.
      */
     public static IgniteBiTuple<Collection<String>, Collection<String>> resolveLocalAddresses(InetAddress locAddr)
-        throws IOException, GridException {
+        throws IOException, IgniteCheckedException {
         assert locAddr != null;
 
         Collection<String> addrs = new ArrayList<>();
@@ -1455,7 +1455,7 @@ public abstract class GridUtils {
             }
 
             if (F.isEmpty(addrs))
-                throw new GridException("No network addresses found (is networking enabled?).");
+                throw new IgniteCheckedException("No network addresses found (is networking enabled?).");
         }
         else
             addresses(locAddr, addrs, hostNames);
@@ -2380,7 +2380,7 @@ public abstract class GridUtils {
             ggHome0 = ggHomeTup.get();
 
         if (ggHome0 != null && !ggHome0.equals(path))
-            throw new GridRuntimeException("Failed to set GRIDGAIN_HOME after it has been already resolved " +
+            throw new IgniteException("Failed to set GRIDGAIN_HOME after it has been already resolved " +
                 "[ggHome=" + ggHome0 + ", newGgHome=" + path + ']');
     }
 
@@ -5599,7 +5599,7 @@ public abstract class GridUtils {
     }
 
     /**
-     * Converts {@link InterruptedException} to {@link GridException}.
+     * Converts {@link InterruptedException} to {@link IgniteCheckedException}.
      *
      * @param mux Mux to wait on.
      * @throws GridInterruptedException If interrupted.
@@ -6072,9 +6072,9 @@ public abstract class GridUtils {
      * @param c Callable to run.
      * @param <R> Return type.
      * @return Return value.
-     * @throws GridException If call failed.
+     * @throws IgniteCheckedException If call failed.
      */
-    @Nullable public static <R> R wrapThreadLoader(ClassLoader ldr, Callable<R> c) throws GridException {
+    @Nullable public static <R> R wrapThreadLoader(ClassLoader ldr, Callable<R> c) throws IgniteCheckedException {
         Thread curThread = Thread.currentThread();
 
         // Get original context class loader.
@@ -6086,11 +6086,11 @@ public abstract class GridUtils {
 
             return c.call();
         }
-        catch (GridException | RuntimeException e) {
+        catch (IgniteCheckedException | RuntimeException e) {
             throw e;
         }
         catch (Exception e) {
-            throw new GridException(e);
+            throw new IgniteCheckedException(e);
         }
         finally {
             // Set the original class loader back.
@@ -6425,14 +6425,14 @@ public abstract class GridUtils {
      * @param str Input string.
      * @param date Date.
      * @return Next token.
-     * @throws GridException Thrown in case of any errors.
+     * @throws IgniteCheckedException Thrown in case of any errors.
      */
-    private static boolean checkNextToken(StringTokenizer t, String str, String date) throws GridException {
+    private static boolean checkNextToken(StringTokenizer t, String str, String date) throws IgniteCheckedException {
         try {
             if (t.nextToken().equals(str))
                 return true;
             else
-                throw new GridException("Invalid date format: " + date);
+                throw new IgniteCheckedException("Invalid date format: " + date);
         }
         catch (NoSuchElementException ignored) {
             return false;
@@ -6443,9 +6443,9 @@ public abstract class GridUtils {
      *
      * @param str ISO date.
      * @return Calendar instance.
-     * @throws GridException Thrown in case of any errors.
+     * @throws IgniteCheckedException Thrown in case of any errors.
      */
-    public static Calendar parseIsoDate(String str) throws GridException {
+    public static Calendar parseIsoDate(String str) throws IgniteCheckedException {
         StringTokenizer t = new StringTokenizer(str, "+-:.TZ", true);
 
         Calendar cal = Calendar.getInstance();
@@ -6521,7 +6521,7 @@ public abstract class GridUtils {
                         cal.set(Calendar.MILLISECOND, 0);
                 }
                 else
-                    throw new GridException("Invalid date format: " + str);
+                    throw new IgniteCheckedException("Invalid date format: " + str);
             }
             else {
                 cal.set(Calendar.SECOND, 0);
@@ -6530,12 +6530,12 @@ public abstract class GridUtils {
 
             if (!"Z".equals(tok)) {
                 if (!"+".equals(tok) && !"-".equals(tok))
-                    throw new GridException("Invalid date format: " + str);
+                    throw new IgniteCheckedException("Invalid date format: " + str);
 
                 boolean plus = "+".equals(tok);
 
                 if (!t.hasMoreTokens())
-                    throw new GridException("Invalid date format: " + str);
+                    throw new IgniteCheckedException("Invalid date format: " + str);
 
                 tok = t.nextToken();
 
@@ -6552,7 +6552,7 @@ public abstract class GridUtils {
                     if (checkNextToken(t, ":", str) && t.hasMoreTokens())
                         tzMin = Integer.parseInt(t.nextToken());
                     else
-                        throw new GridException("Invalid date format: " + str);
+                        throw new IgniteCheckedException("Invalid date format: " + str);
                 }
 
                 if (plus)
@@ -6564,7 +6564,7 @@ public abstract class GridUtils {
                 cal.setTimeZone(TimeZone.getTimeZone("GMT"));
         }
         catch (NumberFormatException ex) {
-            throw new GridException("Invalid date format: " + str, ex);
+            throw new IgniteCheckedException("Invalid date format: " + str, ex);
         }
 
         return cal;
@@ -6656,13 +6656,13 @@ public abstract class GridUtils {
     }
 
     /**
-     * Casts this throwable as {@link GridException}. Creates wrapping
-     * {@link GridException}, if needed.
+     * Casts this throwable as {@link IgniteCheckedException}. Creates wrapping
+     * {@link IgniteCheckedException}, if needed.
      *
      * @param t Throwable to cast.
      * @return Grid exception.
      */
-    public static GridException cast(Throwable t) {
+    public static IgniteCheckedException cast(Throwable t) {
         assert t != null;
 
         while (true) {
@@ -6675,13 +6675,13 @@ public abstract class GridUtils {
                 continue;
             }
 
-            if (t instanceof GridException)
-                return (GridException)t;
+            if (t instanceof IgniteCheckedException)
+                return (IgniteCheckedException)t;
 
-            if (!(t instanceof GridRuntimeException) || t.getCause() == null)
-                return new GridException(t);
+            if (!(t instanceof IgniteException) || t.getCause() == null)
+                return new IgniteCheckedException(t);
 
-            assert t.getCause() != null; // ...and it is GridRuntimeException.
+            assert t.getCause() != null; // ...and it is IgniteException.
 
             t = t.getCause();
         }
@@ -6991,14 +6991,14 @@ public abstract class GridUtils {
      *
      * @param fut Future.
      * @return Future result.
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
-    public static <T> T get(Future<T> fut) throws GridException {
+    public static <T> T get(Future<T> fut) throws IgniteCheckedException {
         try {
             return fut.get();
         }
         catch (ExecutionException e) {
-            throw new GridException(e.getCause());
+            throw new IgniteCheckedException(e.getCause());
         }
         catch (InterruptedException e) {
             Thread.currentThread().interrupt();
@@ -7006,7 +7006,7 @@ public abstract class GridUtils {
             throw new GridInterruptedException(e);
         }
         catch (CancellationException e) {
-            throw new GridException(e);
+            throw new IgniteCheckedException(e);
         }
     }
 
@@ -7226,7 +7226,7 @@ public abstract class GridUtils {
                     try {
                         f.get();
                     }
-                    catch (GridException e) {
+                    catch (IgniteCheckedException e) {
                         U.error(log, "Failed to execute future: " + f, e);
                     }
                 }
@@ -7483,11 +7483,11 @@ public abstract class GridUtils {
             }
         }
         catch (Exception e) {
-            throw new GridRuntimeException("Failed to get field value [fieldName=" + fieldName + ", obj=" + obj + ']',
+            throw new IgniteException("Failed to get field value [fieldName=" + fieldName + ", obj=" + obj + ']',
                 e);
         }
 
-        throw new GridRuntimeException("Failed to get field value [fieldName=" + fieldName + ", obj=" + obj + ']');
+        throw new IgniteException("Failed to get field value [fieldName=" + fieldName + ", obj=" + obj + ']');
     }
 
     /**
@@ -7496,9 +7496,9 @@ public abstract class GridUtils {
      * @param cls Class.
      * @param fieldName Field name.
      * @return Field value.
-     * @throws GridException If static field with given name cannot be retreived.
+     * @throws IgniteCheckedException If static field with given name cannot be retreived.
      */
-    public static <T> T field(Class<?> cls, String fieldName) throws GridException {
+    public static <T> T field(Class<?> cls, String fieldName) throws IgniteCheckedException {
         assert cls != null;
         assert fieldName != null;
 
@@ -7507,7 +7507,7 @@ public abstract class GridUtils {
                 for (Field field : c.getDeclaredFields()) {
                     if (field.getName().equals(fieldName)) {
                         if (!Modifier.isStatic(field.getModifiers()))
-                            throw new GridException("Failed to get class field (field is not static) [cls=" +
+                            throw new IgniteCheckedException("Failed to get class field (field is not static) [cls=" +
                                 cls + ", fieldName=" + fieldName + ']');
 
                         boolean accessible = field.isAccessible();
@@ -7530,11 +7530,11 @@ public abstract class GridUtils {
             }
         }
         catch (Exception e) {
-            throw new GridException("Failed to get field value [fieldName=" + fieldName + ", cls=" + cls + ']',
+            throw new IgniteCheckedException("Failed to get field value [fieldName=" + fieldName + ", cls=" + cls + ']',
                 e);
         }
 
-        throw new GridException("Failed to get field value (field was not found) [fieldName=" + fieldName +
+        throw new IgniteCheckedException("Failed to get field value (field was not found) [fieldName=" + fieldName +
             ", cls=" + cls + ']');
     }
 
@@ -7547,10 +7547,10 @@ public abstract class GridUtils {
      * @param paramTypes Parameter types.
      * @param params Parameters.
      * @return Field value.
-     * @throws GridException If static field with given name cannot be retreived.
+     * @throws IgniteCheckedException If static field with given name cannot be retreived.
      */
     public static <T> T invoke(@Nullable Class<?> cls, @Nullable Object obj, String mtdName,
-        Class[] paramTypes, Object... params) throws GridException {
+        Class[] paramTypes, Object... params) throws IgniteCheckedException {
         assert cls != null || obj != null;
         assert mtdName != null;
 
@@ -7583,11 +7583,11 @@ public abstract class GridUtils {
             }
         }
         catch (Exception e) {
-            throw new GridException("Failed to invoke [mtdName=" + mtdName + ", cls=" + cls + ']',
+            throw new IgniteCheckedException("Failed to invoke [mtdName=" + mtdName + ", cls=" + cls + ']',
                 e);
         }
 
-        throw new GridException("Failed to invoke (method was not found) [mtdName=" + mtdName +
+        throw new IgniteCheckedException("Failed to invoke (method was not found) [mtdName=" + mtdName +
             ", cls=" + cls + ']');
     }
 
@@ -7627,7 +7627,7 @@ public abstract class GridUtils {
             }
         }
         catch (Exception e) {
-            throw new GridRuntimeException(
+            throw new IgniteException(
                 "Failed to get property value [property=" + propName + ", obj=" + obj + ']', e);
         }
     }
@@ -7638,9 +7638,9 @@ public abstract class GridUtils {
      * @param cls Class.
      * @param fieldName Field name.
      * @return Field value.
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
-    public static <T> T staticField(Class<?> cls, String fieldName) throws GridException {
+    public static <T> T staticField(Class<?> cls, String fieldName) throws IgniteCheckedException {
         assert cls != null;
         assert fieldName != null;
 
@@ -7661,10 +7661,10 @@ public abstract class GridUtils {
                 }
         }
         catch (Exception e) {
-            throw new GridException("Failed to get field value [fieldName=" + fieldName + ", cls=" + cls + ']', e);
+            throw new IgniteCheckedException("Failed to get field value [fieldName=" + fieldName + ", cls=" + cls + ']', e);
         }
 
-        throw new GridException("Failed to get field value [fieldName=" + fieldName + ", cls=" + cls + ']');
+        throw new IgniteCheckedException("Failed to get field value [fieldName=" + fieldName + ", cls=" + cls + ']');
     }
 
     /**
@@ -7704,9 +7704,9 @@ public abstract class GridUtils {
      *
      * @return Tuple with root log and no-op appender instances. No-op appender can be {@code null}
      *      if it did not found in classpath. Notice that in this case logging is not suppressed.
-     * @throws GridException In case of failure to add no-op logger for Log4j.
+     * @throws IgniteCheckedException In case of failure to add no-op logger for Log4j.
      */
-    public static IgniteBiTuple<Object, Object> addLog4jNoOpLogger() throws GridException {
+    public static IgniteBiTuple<Object, Object> addLog4jNoOpLogger() throws IgniteCheckedException {
         Object rootLog;
         Object nullApp;
 
@@ -7730,7 +7730,7 @@ public abstract class GridUtils {
             rootLog.getClass().getMethod("addAppender", appCls).invoke(rootLog, nullApp);
         }
         catch (Exception e) {
-            throw new GridException("Failed to add no-op logger for Log4j.", e);
+            throw new IgniteCheckedException("Failed to add no-op logger for Log4j.", e);
         }
 
         return new IgniteBiTuple<>(rootLog, nullApp);
@@ -7740,9 +7740,9 @@ public abstract class GridUtils {
      * Removes previously added no-op logger via method {@link #addLog4jNoOpLogger}.
      *
      * @param t Tuple with root log and null appender instances.
-     * @throws GridException In case of failure to remove previously added no-op logger for Log4j.
+     * @throws IgniteCheckedException In case of failure to remove previously added no-op logger for Log4j.
      */
-    public static void removeLog4jNoOpLogger(IgniteBiTuple<Object, Object> t) throws GridException {
+    public static void removeLog4jNoOpLogger(IgniteBiTuple<Object, Object> t) throws IgniteCheckedException {
         Object rootLog = t.get1();
         Object nullApp = t.get2();
 
@@ -7755,7 +7755,7 @@ public abstract class GridUtils {
             rootLog.getClass().getMethod("removeAppender", appenderCls).invoke(rootLog, nullApp);
         }
         catch (Exception e) {
-            throw new GridException("Failed to remove previously added no-op logger for Log4j.", e);
+            throw new IgniteCheckedException("Failed to remove previously added no-op logger for Log4j.", e);
         }
     }
 
@@ -8148,9 +8148,9 @@ public abstract class GridUtils {
      * {@link org.apache.ignite.lifecycle.LifecycleAware} interface and executes {@link org.apache.ignite.lifecycle.LifecycleAware#start} method.
      *
      * @param objs Objects.
-     * @throws GridException If {@link org.apache.ignite.lifecycle.LifecycleAware#start} fails.
+     * @throws IgniteCheckedException If {@link org.apache.ignite.lifecycle.LifecycleAware#start} fails.
      */
-    public static void startLifecycleAware(Iterable<?> objs) throws GridException {
+    public static void startLifecycleAware(Iterable<?> objs) throws IgniteCheckedException {
         for (Object obj : objs) {
             if (obj instanceof LifecycleAware)
                 ((LifecycleAware)obj).start();
@@ -8170,7 +8170,7 @@ public abstract class GridUtils {
                 try {
                     ((LifecycleAware)obj).stop();
                 }
-                catch (GridException e) {
+                catch (IgniteCheckedException e) {
                     U.error(log, "Failed to stop component (ignoring): " + obj, e);
                 }
             }
@@ -8213,9 +8213,9 @@ public abstract class GridUtils {
      *
      * @param node Grid node.
      * @return Inet addresses for given addresses and host names.
-     * @throws GridException If non of addresses can be resolved.
+     * @throws IgniteCheckedException If non of addresses can be resolved.
      */
-    public static Collection<InetAddress> toInetAddresses(ClusterNode node) throws GridException {
+    public static Collection<InetAddress> toInetAddresses(ClusterNode node) throws IgniteCheckedException {
         return toInetAddresses(node.addresses(), node.hostNames());
     }
 
@@ -8226,10 +8226,10 @@ public abstract class GridUtils {
      * @param addrs Addresses.
      * @param hostNames Host names.
      * @return Inet addresses for given addresses and host names.
-     * @throws GridException If non of addresses can be resolved.
+     * @throws IgniteCheckedException If non of addresses can be resolved.
      */
     public static Collection<InetAddress> toInetAddresses(Collection<String> addrs,
-        Collection<String> hostNames) throws GridException {
+        Collection<String> hostNames) throws IgniteCheckedException {
         List<InetAddress> res = new ArrayList<>(addrs.size());
 
         Iterator<String> hostNamesIt = hostNames.iterator();
@@ -8260,7 +8260,7 @@ public abstract class GridUtils {
         }
 
         if (res.isEmpty())
-            throw new GridException("Addresses can not be resolved [addr=" + addrs +
+            throw new IgniteCheckedException("Addresses can not be resolved [addr=" + addrs +
                 ", hostNames=" + hostNames + ']');
 
         return F.viewListReadOnly(res, F.<InetAddress>identity());
@@ -8320,13 +8320,13 @@ public abstract class GridUtils {
      * @param addrs Addresses.
      * @param port Port.
      * @return Resolved socket addresses.
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
     public static Collection<InetSocketAddress> resolveAddresses(
         IgniteAddressResolver addrRslvr,
         Iterable<String> addrs,
         int port
-    ) throws GridException {
+    ) throws IgniteCheckedException {
         assert addrRslvr != null;
 
         Collection<InetSocketAddress> extAddrs = new HashSet<>();
@@ -8341,7 +8341,7 @@ public abstract class GridUtils {
                     if (extAddrs0 != null)
                         extAddrs.addAll(extAddrs0);
                 }
-                catch (GridException e) {
+                catch (IgniteCheckedException e) {
                     throw new IgniteSpiException("Failed to get mapped external addresses " +
                         "[addrRslvr=" + addrRslvr + ", addr=" + addr + ']', e);
                 }
@@ -8402,7 +8402,7 @@ public abstract class GridUtils {
      * @param userGgHome GridGain home folder provided by user.
      */
     public static void setWorkDirectory(@Nullable String userWorkDir, @Nullable String userGgHome)
-        throws GridException {
+        throws IgniteCheckedException {
         String ggWork0 = ggWork;
 
         if (ggWork0 == null) {
@@ -8425,23 +8425,23 @@ public abstract class GridUtils {
                     String tmpDirPath = System.getProperty("java.io.tmpdir");
 
                     if (tmpDirPath == null)
-                        throw new GridException("Failed to create work directory in OS temp " +
+                        throw new IgniteCheckedException("Failed to create work directory in OS temp " +
                             "(property 'java.io.tmpdir' is null).");
 
                     workDir = new File(tmpDirPath, "gridgain" + File.separator + "work");
                 }
 
                 if (!workDir.isAbsolute())
-                    throw new GridException("Work directory path must be absolute: " + workDir);
+                    throw new IgniteCheckedException("Work directory path must be absolute: " + workDir);
 
                 if (!mkdirs(workDir))
-                    throw new GridException("Work directory does not exist and cannot be created: " + workDir);
+                    throw new IgniteCheckedException("Work directory does not exist and cannot be created: " + workDir);
 
                 if (!workDir.canRead())
-                    throw new GridException("Cannot read from work directory: " + workDir);
+                    throw new IgniteCheckedException("Cannot read from work directory: " + workDir);
 
                 if (!workDir.canWrite())
-                    throw new GridException("Cannot write to work directory: " + workDir);
+                    throw new IgniteCheckedException("Cannot write to work directory: " + workDir);
 
                 ggWork = workDir.getAbsolutePath();
             }
@@ -8468,46 +8468,46 @@ public abstract class GridUtils {
      * @param path Path to resolve.
      * @param delIfExist Flag indicating whether to delete the specify directory or not.
      * @return Resolved work directory.
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
-    public static File resolveWorkDirectory(String path, boolean delIfExist) throws GridException {
+    public static File resolveWorkDirectory(String path, boolean delIfExist) throws IgniteCheckedException {
         File dir = new File(path);
 
         if (!dir.isAbsolute()) {
             String ggWork0 = ggWork;
 
             if (F.isEmpty(ggWork0))
-                throw new GridException("Failed to resolve path (work directory has not been set): " + path);
+                throw new IgniteCheckedException("Failed to resolve path (work directory has not been set): " + path);
 
             dir = new File(ggWork0, dir.getPath());
         }
 
         if (delIfExist && dir.exists()) {
             if (!U.delete(dir))
-                throw new GridException("Failed to delete directory: " + dir);
+                throw new IgniteCheckedException("Failed to delete directory: " + dir);
         }
 
         if (!mkdirs(dir))
-            throw new GridException("Directory does not exist and cannot be created: " + dir);
+            throw new IgniteCheckedException("Directory does not exist and cannot be created: " + dir);
 
         if (!dir.canRead())
-            throw new GridException("Cannot read from directory: " + dir);
+            throw new IgniteCheckedException("Cannot read from directory: " + dir);
 
         if (!dir.canWrite())
-            throw new GridException("Cannot write to directory: " + dir);
+            throw new IgniteCheckedException("Cannot write to directory: " + dir);
 
         return dir;
     }
 
     /**
-     * Creates {@code GridException} with the collection of suppressed exceptions.
+     * Creates {@code IgniteCheckedException} with the collection of suppressed exceptions.
      *
      * @param msg Message.
      * @param suppressed The collections of suppressed exceptions.
-     * @return {@code GridException}.
+     * @return {@code IgniteCheckedException}.
      */
-    public static GridException exceptionWithSuppressed(String msg, @Nullable Collection<Throwable> suppressed) {
-        GridException e = new GridException(msg);
+    public static IgniteCheckedException exceptionWithSuppressed(String msg, @Nullable Collection<Throwable> suppressed) {
+        IgniteCheckedException e = new IgniteCheckedException(msg);
 
         if (suppressed != null) {
             for (Throwable th : suppressed)
@@ -8540,14 +8540,14 @@ public abstract class GridUtils {
      * @param data An array of characters containing hexidecimal digits
      * @return A byte array containing binary data decoded from
      *         the supplied char array.
-     * @throws GridException Thrown if an odd number or illegal of characters is supplied.
+     * @throws IgniteCheckedException Thrown if an odd number or illegal of characters is supplied.
      */
-    public static byte[] decodeHex(char[] data) throws GridException {
+    public static byte[] decodeHex(char[] data) throws IgniteCheckedException {
 
         int len = data.length;
 
         if ((len & 0x01) != 0)
-            throw new GridException("Odd number of characters.");
+            throw new IgniteCheckedException("Odd number of characters.");
 
         byte[] out = new byte[len >> 1];
 
@@ -8573,13 +8573,13 @@ public abstract class GridUtils {
      * @param ch A character to convert to an integer digit
      * @param index The index of the character in the source
      * @return An integer
-     * @throws GridException Thrown if ch is an illegal hex character
+     * @throws IgniteCheckedException Thrown if ch is an illegal hex character
      */
-    public static int toDigit(char ch, int index) throws GridException {
+    public static int toDigit(char ch, int index) throws IgniteCheckedException {
         int digit = Character.digit(ch, 16);
 
         if (digit == -1)
-            throw new GridException("Illegal hexadecimal character " + ch + " at index " + index);
+            throw new IgniteCheckedException("Illegal hexadecimal character " + ch + " at index " + index);
 
         return digit;
     }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/util/GridWeakIterator.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/util/future/GridCompoundFuture.java b/modules/core/src/main/java/org/gridgain/grid/util/future/GridCompoundFuture.java
index c00b8e2..bf89359 100644
--- a/modules/core/src/main/java/org/gridgain/grid/util/future/GridCompoundFuture.java
+++ b/modules/core/src/main/java/org/gridgain/grid/util/future/GridCompoundFuture.java
@@ -9,14 +9,14 @@
 
 package org.gridgain.grid.util.future;
 
+import org.apache.ignite.*;
 import org.apache.ignite.cluster.*;
 import org.apache.ignite.lang.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.cache.*;
 import org.gridgain.grid.kernal.*;
+import org.gridgain.grid.util.tostring.*;
 import org.gridgain.grid.util.typedef.*;
 import org.gridgain.grid.util.typedef.internal.*;
-import org.gridgain.grid.util.tostring.*;
 import org.jdk8.backport.*;
 import org.jetbrains.annotations.*;
 
@@ -98,7 +98,7 @@ public class GridCompoundFuture<T, R> extends GridFutureAdapter<R> {
     }
 
     /** {@inheritDoc} */
-    @Override public boolean cancel() throws GridException {
+    @Override public boolean cancel() throws IgniteCheckedException {
         if (onCancelled()) {
             for (IgniteFuture<T> fut : futs)
                 fut.cancel();
@@ -170,7 +170,7 @@ public class GridCompoundFuture<T, R> extends GridFutureAdapter<R> {
             try {
                 fut.cancel();
             }
-            catch (GridException e) {
+            catch (IgniteCheckedException e) {
                 onDone(e);
             }
     }
@@ -342,7 +342,7 @@ public class GridCompoundFuture<T, R> extends GridFutureAdapter<R> {
 
                 err.compareAndSet(null, e);
             }
-            catch (GridException e) {
+            catch (IgniteCheckedException e) {
                 if (!ignoreFailure(e))
                     U.error(log, "Failed to execute compound future reducer: " + this, e);
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/util/future/GridEmbeddedFuture.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/util/future/GridEmbeddedFuture.java b/modules/core/src/main/java/org/gridgain/grid/util/future/GridEmbeddedFuture.java
index 465630a..346978c 100644
--- a/modules/core/src/main/java/org/gridgain/grid/util/future/GridEmbeddedFuture.java
+++ b/modules/core/src/main/java/org/gridgain/grid/util/future/GridEmbeddedFuture.java
@@ -9,11 +9,12 @@
 
 package org.gridgain.grid.util.future;
 
+import org.apache.ignite.*;
 import org.apache.ignite.lang.*;
 import org.gridgain.grid.*;
 import org.gridgain.grid.kernal.*;
-import org.gridgain.grid.util.typedef.internal.*;
 import org.gridgain.grid.util.lang.*;
+import org.gridgain.grid.util.typedef.internal.*;
 
 import java.io.*;
 
@@ -55,7 +56,7 @@ public class GridEmbeddedFuture<A, B> extends GridFutureAdapter<A> {
                 try {
                     onDone(c.apply(embedded.get(), null));
                 }
-                catch (GridException| RuntimeException e) {
+                catch (IgniteCheckedException| RuntimeException e) {
                     onDone(c.apply(null, e));
                 }
                 catch (Error e) {
@@ -117,7 +118,7 @@ public class GridEmbeddedFuture<A, B> extends GridFutureAdapter<A> {
                             catch (GridClosureException e) {
                                 onDone(e.unwrap());
                             }
-                            catch (GridException | RuntimeException e) {
+                            catch (IgniteCheckedException | RuntimeException e) {
                                 onDone(e);
                             }
                             catch (Error e) {
@@ -133,7 +134,7 @@ public class GridEmbeddedFuture<A, B> extends GridFutureAdapter<A> {
 
                     onDone(e.unwrap());
                 }
-                catch (GridException | RuntimeException e) {
+                catch (IgniteCheckedException | RuntimeException e) {
                     c.apply(null, e);
 
                     onDone(e);
@@ -186,7 +187,7 @@ public class GridEmbeddedFuture<A, B> extends GridFutureAdapter<A> {
 
                                 onDone(e.unwrap());
                             }
-                            catch (GridException | RuntimeException e) {
+                            catch (IgniteCheckedException | RuntimeException e) {
                                 c2.apply(null, e);
 
                                 onDone(e);
@@ -204,7 +205,7 @@ public class GridEmbeddedFuture<A, B> extends GridFutureAdapter<A> {
 
                     onDone(e.unwrap());
                 }
-                catch (GridException | RuntimeException e) {
+                catch (IgniteCheckedException | RuntimeException e) {
                     c1.apply(null, e);
 
                     onDone(e);
@@ -219,7 +220,7 @@ public class GridEmbeddedFuture<A, B> extends GridFutureAdapter<A> {
     }
 
     /** {@inheritDoc} */
-    @Override public boolean cancel() throws GridException {
+    @Override public boolean cancel() throws IgniteCheckedException {
         return embedded.cancel();
     }
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/util/future/GridFinishedFuture.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/util/future/GridFinishedFuture.java b/modules/core/src/main/java/org/gridgain/grid/util/future/GridFinishedFuture.java
index c38861a..5f98641 100644
--- a/modules/core/src/main/java/org/gridgain/grid/util/future/GridFinishedFuture.java
+++ b/modules/core/src/main/java/org/gridgain/grid/util/future/GridFinishedFuture.java
@@ -141,7 +141,7 @@ public class GridFinishedFuture<T> implements IgniteFuture<T>, Externalizable {
     }
 
     /** {@inheritDoc} */
-    @Override public T get() throws GridException {
+    @Override public T get() throws IgniteCheckedException {
         if (err != null)
             throw U.cast(err);
 
@@ -149,12 +149,12 @@ public class GridFinishedFuture<T> implements IgniteFuture<T>, Externalizable {
     }
 
     /** {@inheritDoc} */
-    @Override public T get(long timeout) throws GridException {
+    @Override public T get(long timeout) throws IgniteCheckedException {
         return get();
     }
 
     /** {@inheritDoc} */
-    @Override public T get(long timeout, TimeUnit unit) throws GridException {
+    @Override public T get(long timeout, TimeUnit unit) throws IgniteCheckedException {
         return get();
     }
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/util/future/GridFinishedFutureEx.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/util/future/GridFinishedFutureEx.java b/modules/core/src/main/java/org/gridgain/grid/util/future/GridFinishedFutureEx.java
index 5eb4afa..663cf87 100644
--- a/modules/core/src/main/java/org/gridgain/grid/util/future/GridFinishedFutureEx.java
+++ b/modules/core/src/main/java/org/gridgain/grid/util/future/GridFinishedFutureEx.java
@@ -9,8 +9,8 @@
 
 package org.gridgain.grid.util.future;
 
+import org.apache.ignite.*;
 import org.apache.ignite.lang.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.util.lang.*;
 import org.gridgain.grid.util.typedef.internal.*;
 import org.jetbrains.annotations.*;
@@ -117,7 +117,7 @@ public class GridFinishedFutureEx<T> implements IgniteFuture<T>, Externalizable
     }
 
     /** {@inheritDoc} */
-    @Override public T get() throws GridException {
+    @Override public T get() throws IgniteCheckedException {
         if (err != null)
             throw U.cast(err);
 
@@ -125,12 +125,12 @@ public class GridFinishedFutureEx<T> implements IgniteFuture<T>, Externalizable
     }
 
     /** {@inheritDoc} */
-    @Override public T get(long timeout) throws GridException {
+    @Override public T get(long timeout) throws IgniteCheckedException {
         return get();
     }
 
     /** {@inheritDoc} */
-    @Override public T get(long timeout, TimeUnit unit) throws GridException {
+    @Override public T get(long timeout, TimeUnit unit) throws IgniteCheckedException {
         return get();
     }
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/util/future/GridFutureAdapter.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/util/gridify/GridifyJobAdapter.java b/modules/core/src/main/java/org/gridgain/grid/util/gridify/GridifyJobAdapter.java
index 39f4eef..f19cc45 100644
--- a/modules/core/src/main/java/org/gridgain/grid/util/gridify/GridifyJobAdapter.java
+++ b/modules/core/src/main/java/org/gridgain/grid/util/gridify/GridifyJobAdapter.java
@@ -9,9 +9,9 @@
 
 package org.gridgain.grid.util.gridify;
 
+import org.apache.ignite.*;
 import org.apache.ignite.compute.*;
 import org.apache.ignite.compute.gridify.*;
-import org.gridgain.grid.*;
 
 import java.lang.reflect.*;
 
@@ -54,9 +54,9 @@ public class GridifyJobAdapter extends ComputeJobAdapter {
      * out of this method.
      *
      * @return {@inheritDoc}
-     * @throws GridException {@inheritDoc}
+     * @throws IgniteCheckedException {@inheritDoc}
      */
-    @Override public Object execute() throws GridException {
+    @Override public Object execute() throws IgniteCheckedException {
         GridifyArgument arg = argument(0);
 
         try {
@@ -70,7 +70,7 @@ public class GridifyJobAdapter extends ComputeJobAdapter {
                     mtd.setAccessible(true);
                 }
                 catch (SecurityException e) {
-                    throw new GridException("Got security exception when attempting to soften access control for " +
+                    throw new IgniteCheckedException("Got security exception when attempting to soften access control for " +
                         "@Gridify method: " + mtd, e);
                 }
 
@@ -84,16 +84,16 @@ public class GridifyJobAdapter extends ComputeJobAdapter {
             return mtd.invoke(obj, arg.getMethodParameters());
         }
         catch (InvocationTargetException e) {
-            if (e.getTargetException() instanceof GridException)
-                throw (GridException)e.getTargetException();
+            if (e.getTargetException() instanceof IgniteCheckedException)
+                throw (IgniteCheckedException)e.getTargetException();
 
-            throw new GridException("Failed to invoke a method due to user exception.", e.getTargetException());
+            throw new IgniteCheckedException("Failed to invoke a method due to user exception.", e.getTargetException());
         }
         catch (IllegalAccessException e) {
-            throw new GridException("Failed to access method for execution.", e);
+            throw new IgniteCheckedException("Failed to access method for execution.", e);
         }
         catch (NoSuchMethodException e) {
-            throw new GridException("Failed to find method for execution.", e);
+            throw new IgniteCheckedException("Failed to find method for execution.", e);
         }
     }
 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/util/ipc/GridIpcEndpoint.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/util/ipc/GridIpcEndpointBindException.java b/modules/core/src/main/java/org/gridgain/grid/util/ipc/GridIpcEndpointBindException.java
index c625a83..6bc389a 100644
--- a/modules/core/src/main/java/org/gridgain/grid/util/ipc/GridIpcEndpointBindException.java
+++ b/modules/core/src/main/java/org/gridgain/grid/util/ipc/GridIpcEndpointBindException.java
@@ -9,12 +9,12 @@
 
 package org.gridgain.grid.util.ipc;
 
-import org.gridgain.grid.*;
+import org.apache.ignite.*;
 
 /**
  * Represents exception occurred during IPC endpoint binding.
  */
-public class GridIpcEndpointBindException extends GridException {
+public class GridIpcEndpointBindException extends IgniteCheckedException {
     /** */
     private static final long serialVersionUID = 0L;
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/util/ipc/GridIpcEndpointFactory.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/util/ipc/GridIpcToNioAdapter.java b/modules/core/src/main/java/org/gridgain/grid/util/ipc/GridIpcToNioAdapter.java
index cc52959..0222add 100644
--- a/modules/core/src/main/java/org/gridgain/grid/util/ipc/GridIpcToNioAdapter.java
+++ b/modules/core/src/main/java/org/gridgain/grid/util/ipc/GridIpcToNioAdapter.java
@@ -121,15 +121,15 @@ public class GridIpcToNioAdapter<T> {
             }
         }
         catch (Exception e) {
-            chain.onExceptionCaught(ses, new GridException("Failed to read from IPC endpoint.", e));
+            chain.onExceptionCaught(ses, new IgniteCheckedException("Failed to read from IPC endpoint.", e));
         }
         finally {
             try {
                 // Assuming remote end closed connection - pushing event from head to tail.
                 chain.onSessionClosed(ses);
             }
-            catch (GridException e) {
-                chain.onExceptionCaught(ses, new GridException("Failed to process session close event " +
+            catch (IgniteCheckedException e) {
+                chain.onExceptionCaught(ses, new IgniteCheckedException("Failed to process session close event " +
                     "for IPC endpoint.", e));
             }
         }
@@ -152,7 +152,7 @@ public class GridIpcToNioAdapter<T> {
 
             metricsLsnr.onBytesSent(cnt);
         }
-        catch (IOException | GridException e) {
+        catch (IOException | IgniteCheckedException e) {
             return new GridNioFinishedFuture<Object>(e);
         }
 
@@ -171,17 +171,17 @@ public class GridIpcToNioAdapter<T> {
         }
 
         /** {@inheritDoc} */
-        @Override public void onSessionOpened(GridNioSession ses) throws GridException {
+        @Override public void onSessionOpened(GridNioSession ses) throws IgniteCheckedException {
             proceedSessionOpened(ses);
         }
 
         /** {@inheritDoc} */
-        @Override public void onSessionClosed(GridNioSession ses) throws GridException {
+        @Override public void onSessionClosed(GridNioSession ses) throws IgniteCheckedException {
             proceedSessionClosed(ses);
         }
 
         /** {@inheritDoc} */
-        @Override public void onExceptionCaught(GridNioSession ses, GridException ex) throws GridException {
+        @Override public void onExceptionCaught(GridNioSession ses, IgniteCheckedException ex) throws IgniteCheckedException {
             proceedExceptionCaught(ses, ex);
         }
 
@@ -193,12 +193,12 @@ public class GridIpcToNioAdapter<T> {
         }
 
         /** {@inheritDoc} */
-        @Override public void onMessageReceived(GridNioSession ses, Object msg) throws GridException {
+        @Override public void onMessageReceived(GridNioSession ses, Object msg) throws IgniteCheckedException {
             proceedMessageReceived(ses, msg);
         }
 
         /** {@inheritDoc} */
-        @Override public GridNioFuture<?> onPauseReads(GridNioSession ses) throws GridException {
+        @Override public GridNioFuture<?> onPauseReads(GridNioSession ses) throws IgniteCheckedException {
             // This call should be synced externally to avoid races.
             boolean b = latchRef.compareAndSet(null, new CountDownLatch(1));
 
@@ -208,7 +208,7 @@ public class GridIpcToNioAdapter<T> {
         }
 
         /** {@inheritDoc} */
-        @Override public GridNioFuture<?> onResumeReads(GridNioSession ses) throws GridException {
+        @Override public GridNioFuture<?> onResumeReads(GridNioSession ses) throws IgniteCheckedException {
             // This call should be synced externally to avoid races.
             CountDownLatch latch = latchRef.getAndSet(null);
 
@@ -231,12 +231,12 @@ public class GridIpcToNioAdapter<T> {
         }
 
         /** {@inheritDoc} */
-        @Override public void onSessionIdleTimeout(GridNioSession ses) throws GridException {
+        @Override public void onSessionIdleTimeout(GridNioSession ses) throws IgniteCheckedException {
             proceedSessionIdleTimeout(ses);
         }
 
         /** {@inheritDoc} */
-        @Override public void onSessionWriteTimeout(GridNioSession ses) throws GridException {
+        @Override public void onSessionWriteTimeout(GridNioSession ses) throws IgniteCheckedException {
             proceedSessionWriteTimeout(ses);
         }
     }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/util/ipc/loopback/GridIpcClientTcpEndpoint.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/util/ipc/shmem/GridIpcOutOfSystemResourcesException.java b/modules/core/src/main/java/org/gridgain/grid/util/ipc/shmem/GridIpcOutOfSystemResourcesException.java
index cf56700..ef01846 100644
--- a/modules/core/src/main/java/org/gridgain/grid/util/ipc/shmem/GridIpcOutOfSystemResourcesException.java
+++ b/modules/core/src/main/java/org/gridgain/grid/util/ipc/shmem/GridIpcOutOfSystemResourcesException.java
@@ -9,14 +9,14 @@
 
 package org.gridgain.grid.util.ipc.shmem;
 
-import org.gridgain.grid.*;
+import org.apache.ignite.*;
 import org.jetbrains.annotations.*;
 
 /**
  * Thrown when IPC runs out of system resources (for example, no more free shared memory is
  * available in operating system).
  */
-public class GridIpcOutOfSystemResourcesException extends GridException {
+public class GridIpcOutOfSystemResourcesException extends IgniteCheckedException {
     /** */
     private static final long serialVersionUID = 0L;
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/util/ipc/shmem/GridIpcSharedMemoryClientEndpoint.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/util/ipc/shmem/GridIpcSharedMemoryInputStream.java b/modules/core/src/main/java/org/gridgain/grid/util/ipc/shmem/GridIpcSharedMemoryInputStream.java
index 1602be6..bcf3949 100644
--- a/modules/core/src/main/java/org/gridgain/grid/util/ipc/shmem/GridIpcSharedMemoryInputStream.java
+++ b/modules/core/src/main/java/org/gridgain/grid/util/ipc/shmem/GridIpcSharedMemoryInputStream.java
@@ -9,7 +9,7 @@
 
 package org.gridgain.grid.util.ipc.shmem;
 
-import org.gridgain.grid.*;
+import org.apache.ignite.*;
 import org.gridgain.grid.util.typedef.internal.*;
 
 import java.io.*;
@@ -43,7 +43,7 @@ public class GridIpcSharedMemoryInputStream extends InputStream {
 
             return buf[0] & 0xFF;
         }
-        catch (GridException e) {
+        catch (IgniteCheckedException e) {
             throw new IOException(e);
         }
     }
@@ -53,7 +53,7 @@ public class GridIpcSharedMemoryInputStream extends InputStream {
         try {
             return in.read(b, off, len, 0);
         }
-        catch (GridException e) {
+        catch (IgniteCheckedException e) {
             throw new IOException(e);
         }
     }
@@ -63,7 +63,7 @@ public class GridIpcSharedMemoryInputStream extends InputStream {
         try {
             return in.unreadCount();
         }
-        catch (GridException e) {
+        catch (IgniteCheckedException e) {
             throw new IOException(e);
         }
     }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/util/ipc/shmem/GridIpcSharedMemoryNativeLoader.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/util/ipc/shmem/GridIpcSharedMemoryOperationTimedoutException.java b/modules/core/src/main/java/org/gridgain/grid/util/ipc/shmem/GridIpcSharedMemoryOperationTimedoutException.java
index 063149c..6be9d11 100644
--- a/modules/core/src/main/java/org/gridgain/grid/util/ipc/shmem/GridIpcSharedMemoryOperationTimedoutException.java
+++ b/modules/core/src/main/java/org/gridgain/grid/util/ipc/shmem/GridIpcSharedMemoryOperationTimedoutException.java
@@ -9,14 +9,14 @@
 
 package org.gridgain.grid.util.ipc.shmem;
 
-import org.gridgain.grid.*;
+import org.apache.ignite.*;
 import org.jetbrains.annotations.*;
 
 /**
  * Thrown when IPC operation (such as {@link GridIpcSharedMemorySpace#wait(long)})
  * has timed out.
  */
-public class GridIpcSharedMemoryOperationTimedoutException extends GridException {
+public class GridIpcSharedMemoryOperationTimedoutException extends IgniteCheckedException {
     /** */
     private static final long serialVersionUID = 0L;
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/util/ipc/shmem/GridIpcSharedMemoryOutputStream.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/util/ipc/shmem/GridIpcSharedMemoryOutputStream.java b/modules/core/src/main/java/org/gridgain/grid/util/ipc/shmem/GridIpcSharedMemoryOutputStream.java
index 51a793f..220d612 100644
--- a/modules/core/src/main/java/org/gridgain/grid/util/ipc/shmem/GridIpcSharedMemoryOutputStream.java
+++ b/modules/core/src/main/java/org/gridgain/grid/util/ipc/shmem/GridIpcSharedMemoryOutputStream.java
@@ -9,7 +9,7 @@
 
 package org.gridgain.grid.util.ipc.shmem;
 
-import org.gridgain.grid.*;
+import org.apache.ignite.*;
 import org.gridgain.grid.util.typedef.internal.*;
 
 import java.io.*;
@@ -44,7 +44,7 @@ public class GridIpcSharedMemoryOutputStream extends OutputStream {
         try {
             out.write(b, off, len, 0);
         }
-        catch (GridException e) {
+        catch (IgniteCheckedException e) {
             throw new IOException(e);
         }
     }
diff --git a/modules/core/src/main/java/org/gridgain/grid/util/GridReflectionCache.java b/modules/core/src/main/java/org/gridgain/grid/util/GridReflectionCache.java
index c6f3a94..0e1660f 100644
--- a/modules/core/src/main/java/org/gridgain/grid/util/GridReflectionCache.java
+++ b/modules/core/src/main/java/org/gridgain/grid/util/GridReflectionCache.java
@@ -9,8 +9,8 @@
 
 package org.gridgain.grid.util;
 
+import org.apache.ignite.*;
 import org.apache.ignite.lang.*;
-import org.gridgain.grid.*;
 import org.jetbrains.annotations.*;
 
 import java.io.*;
@@ -80,9 +80,9 @@ public class GridReflectionCache implements Externalizable {
      *
      * @param o Key to get affinity key for.
      * @return Value of the field for given object or {@code null} if field was not found.
      * @throws GridException If failed.
      */
-    @Nullable public Object firstFieldValue(Object o) throws GridException {
+    @Nullable public Object firstFieldValue(Object o) throws IgniteCheckedException {
         assert o != null;
 
         Field f = firstField(o.getClass());
@@ -92,7 +92,7 @@ public class GridReflectionCache implements Externalizable {
                 return f.get(o);
             }
             catch (IllegalAccessException e) {
-                throw new GridException("Failed to access field for object [field=" + f + ", obj=" + o + ']', e);
+                throw new IgniteCheckedException("Failed to access field for object [field=" + f + ", obj=" + o + ']', e);
             }
         }
 
@@ -104,9 +104,9 @@ public class GridReflectionCache implements Externalizable {
      *
      * @param o Key to get affinity key for.
      * @return Method return value for given object or {@code null} if method was not found.
      * @throws GridException If failed.
      */
-    @Nullable public Object firstMethodValue(Object o) throws GridException {
+    @Nullable public Object firstMethodValue(Object o) throws IgniteCheckedException {
         assert o != null;
 
         Method m = firstMethod(o.getClass());
@@ -116,7 +116,7 @@ public class GridReflectionCache implements Externalizable {
                 return m.invoke(o);
             }
             catch (IllegalAccessException | InvocationTargetException e) {
-                throw new GridException("Failed to invoke method for object [mtd=" + m + ", obj=" + o + ']', e);
+                throw new IgniteCheckedException("Failed to invoke method for object [mtd=" + m + ", obj=" + o + ']', e);
             }
         }
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/util/GridSpiCloseableIteratorWrapper.java
----------------------------------------------------------------------
@@ -80,9 +80,9 @@ public class GridReflectionCache implements Externalizable {
      * @param o Key to get affinity key for.
      * @return Value of the field for given object or {@code null} if field was not found.
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
@@ -104,9 +104,9 @@ public class GridReflectionCache implements Externalizable {
      * @param o Key to get affinity key for.
      * @return Method return value for given object or {@code null} if method was not found.
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
diff --git a/modules/core/src/main/java/org/gridgain/grid/util/GridWeakIterator.java b/modules/core/src/main/java/org/gridgain/grid/util/GridWeakIterator.java
index ab9ebdf..62e3b4b 100644
--- a/modules/core/src/main/java/org/gridgain/grid/util/GridWeakIterator.java
+++ b/modules/core/src/main/java/org/gridgain/grid/util/GridWeakIterator.java
@@ -1,6 +1,6 @@
 package org.gridgain.grid.util;
 
-import org.gridgain.grid.*;
+import org.apache.ignite.*;
 import org.gridgain.grid.util.lang.*;
 
 import java.lang.ref.*;
@@ -30,9 +30,9 @@ public class GridWeakIterator<T> extends WeakReference<Iterator<T>> {
     /**
      * Closes iterator.
      *
      * @throws GridException If failed.
      */
-    public void close() throws GridException {
+    public void close() throws IgniteCheckedException {
         it.close();
     }
 }
\ No newline at end of file

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/util/future/GridCompoundFuture.java
----------------------------------------------------------------------
@@ -30,9 +30,9 @@ public class GridWeakIterator<T> extends WeakReference<Iterator<T>> {
      * Closes iterator.
      *
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
diff --git a/modules/core/src/main/java/org/gridgain/grid/util/future/GridFutureAdapter.java b/modules/core/src/main/java/org/gridgain/grid/util/future/GridFutureAdapter.java
index 7d41038..7d675a7 100644
--- a/modules/core/src/main/java/org/gridgain/grid/util/future/GridFutureAdapter.java
+++ b/modules/core/src/main/java/org/gridgain/grid/util/future/GridFutureAdapter.java
@@ -186,7 +186,7 @@ public class GridFutureAdapter<R> extends AbstractQueuedSynchronizer implements
     }
 
     /** {@inheritDoc} */
-    @Override public R get() throws GridException {
+    @Override public R get() throws IgniteCheckedException {
         checkValid();
 
         try {
@@ -209,13 +209,13 @@ public class GridFutureAdapter<R> extends AbstractQueuedSynchronizer implements
     }
 
     /** {@inheritDoc} */
-    @Override public R get(long timeout) throws GridException {
+    @Override public R get(long timeout) throws IgniteCheckedException {
         // Do not replace with static import, as it may not compile.
         return get(timeout, TimeUnit.MILLISECONDS);
     }
 
     /** {@inheritDoc} */
-    @Override public R get(long timeout, TimeUnit unit) throws GridException {
+    @Override public R get(long timeout, TimeUnit unit) throws IgniteCheckedException {
         A.ensure(timeout >= 0, "timeout cannot be negative: " + timeout);
         A.notNull(unit, "unit");
 
@@ -236,9 +236,9 @@ public class GridFutureAdapter<R> extends AbstractQueuedSynchronizer implements
      * @return Result.
      * @throws InterruptedException If interrupted.
      * @throws org.apache.ignite.lang.IgniteFutureTimeoutException If timeout reached before computation completed.
      * @throws GridException If error occurred.
      */
-    @Nullable protected R get0(long nanosTimeout) throws InterruptedException, GridException {
+    @Nullable protected R get0(long nanosTimeout) throws InterruptedException, IgniteCheckedException {
         if (endTime == 0 && !tryAcquireSharedNanos(0, nanosTimeout))
             throw new IgniteFutureTimeoutException("Timeout was reached before computation completed.");
 
@@ -388,7 +388,7 @@ public class GridFutureAdapter<R> extends AbstractQueuedSynchronizer implements
      * and call {@link #onCancelled()} callback explicitly if cancellation
      * indeed did happen.
      */
-    @Override public boolean cancel() throws GridException {
+    @Override public boolean cancel() throws IgniteCheckedException {
         checkValid();
 
         return false;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/util/future/GridFutureAdapterEx.java
----------------------------------------------------------------------
@@ -236,9 +236,9 @@ public class GridFutureAdapter<R> extends AbstractQueuedSynchronizer implements
      * @throws InterruptedException If interrupted.
      * @throws org.apache.ignite.lang.IgniteFutureTimeoutException If timeout reached before computation completed.
-     * @throws GridException If error occurred.
+     * @throws IgniteCheckedException If error occurred.
      */
diff --git a/modules/core/src/main/java/org/gridgain/grid/util/future/GridFutureAdapterEx.java b/modules/core/src/main/java/org/gridgain/grid/util/future/GridFutureAdapterEx.java
index 245b504..84f9eb5 100644
--- a/modules/core/src/main/java/org/gridgain/grid/util/future/GridFutureAdapterEx.java
+++ b/modules/core/src/main/java/org/gridgain/grid/util/future/GridFutureAdapterEx.java
@@ -9,11 +9,12 @@
 
 package org.gridgain.grid.util.future;
 
+import org.apache.ignite.*;
 import org.apache.ignite.lang.*;
 import org.gridgain.grid.*;
-import org.gridgain.grid.util.typedef.internal.*;
 import org.gridgain.grid.util.lang.*;
 import org.gridgain.grid.util.tostring.*;
+import org.gridgain.grid.util.typedef.internal.*;
 import org.jdk8.backport.*;
 import org.jetbrains.annotations.*;
 
@@ -134,7 +135,7 @@ public class GridFutureAdapterEx<R> extends AbstractQueuedSynchronizer implement
     }
 
     /** {@inheritDoc} */
-    @Override public R get() throws GridException {
+    @Override public R get() throws IgniteCheckedException {
         checkValid();
 
         try {
@@ -157,13 +158,13 @@ public class GridFutureAdapterEx<R> extends AbstractQueuedSynchronizer implement
     }
 
     /** {@inheritDoc} */
-    @Override public R get(long timeout) throws GridException {
+    @Override public R get(long timeout) throws IgniteCheckedException {
         // Do not replace with static import, as it may not compile.
         return get(timeout, TimeUnit.MILLISECONDS);
     }
 
     /** {@inheritDoc} */
-    @Override public R get(long timeout, TimeUnit unit) throws GridException {
+    @Override public R get(long timeout, TimeUnit unit) throws IgniteCheckedException {
         A.ensure(timeout >= 0, "timeout cannot be negative: " + timeout);
         A.notNull(unit, "unit");
 
@@ -184,9 +185,9 @@ public class GridFutureAdapterEx<R> extends AbstractQueuedSynchronizer implement
      * @return Result.
      * @throws InterruptedException If interrupted.
      * @throws org.apache.ignite.lang.IgniteFutureTimeoutException If timeout reached before computation completed.
      * @throws GridException If error occurred.
      */
-    @Nullable protected R get0(long nanosTimeout) throws InterruptedException, GridException {
+    @Nullable protected R get0(long nanosTimeout) throws InterruptedException, IgniteCheckedException {
         if (endTime == 0 && !tryAcquireSharedNanos(0, nanosTimeout))
             throw new IgniteFutureTimeoutException("Timeout was reached before computation completed.");
 
@@ -333,7 +334,7 @@ public class GridFutureAdapterEx<R> extends AbstractQueuedSynchronizer implement
      * and call {@link #onCancelled()} callback explicitly if cancellation
      * indeed did happen.
      */
-    @Override public boolean cancel() throws GridException {
+    @Override public boolean cancel() throws IgniteCheckedException {
         checkValid();
 
         return false;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/util/gridify/GridifyArgumentBuilder.java
----------------------------------------------------------------------
@@ -184,9 +185,9 @@ public class GridFutureAdapterEx<R> extends AbstractQueuedSynchronizer implement
      * @throws InterruptedException If interrupted.
      * @throws org.apache.ignite.lang.IgniteFutureTimeoutException If timeout reached before computation completed.
-     * @throws GridException If error occurred.
+     * @throws IgniteCheckedException If error occurred.
      */
diff --git a/modules/core/src/main/java/org/gridgain/grid/util/gridify/GridifyArgumentBuilder.java b/modules/core/src/main/java/org/gridgain/grid/util/gridify/GridifyArgumentBuilder.java
index a2433f3..0bec52f 100644
--- a/modules/core/src/main/java/org/gridgain/grid/util/gridify/GridifyArgumentBuilder.java
+++ b/modules/core/src/main/java/org/gridgain/grid/util/gridify/GridifyArgumentBuilder.java
@@ -9,9 +9,9 @@
 
 package org.gridgain.grid.util.gridify;
 
+import org.apache.ignite.*;
 import org.apache.ignite.compute.gridify.*;
 import org.apache.ignite.compute.gridify.aop.*;
-import org.gridgain.grid.*;
 
 import java.lang.annotation.*;
 import java.util.*;
@@ -104,9 +104,9 @@ public final class GridifyArgumentBuilder {
      * @param arg Task argument contains all necessary data for method invoke.
      * @param input Input collection..
      * @return Argument for task.
      * @throws GridException In case of error.
      */
-    public GridifyRangeArgument createTaskArgument(GridifyRangeArgument arg, Collection<?> input) throws GridException {
+    public GridifyRangeArgument createTaskArgument(GridifyRangeArgument arg, Collection<?> input) throws IgniteCheckedException {
         GridifyRangeArgument res = new GridifyRangeArgument();
 
         res.setTarget(arg.getTarget());
@@ -131,7 +131,7 @@ public final class GridifyArgumentBuilder {
         Object paramValue = GridifyUtils.collectionToParameter(paramCls, input);
 
         if (paramValue == null)
-            throw new GridException("Failed to create task argument for type: " + paramCls.getName());
+            throw new IgniteCheckedException("Failed to create task argument for type: " + paramCls.getName());
 
         mtdArgs[arg.getParamIndex()] = paramValue;
 
@@ -144,9 +144,9 @@ public final class GridifyArgumentBuilder {
      * @param arg Task argument contains all necessary data for method invoke.
      * @param input Input collection used in job.
      * @return Argument for job.
      * @throws GridException In case of error.
      */
-    public GridifyArgument createJobArgument(GridifyRangeArgument arg, Collection<?> input) throws GridException {
+    public GridifyArgument createJobArgument(GridifyRangeArgument arg, Collection<?> input) throws IgniteCheckedException {
         GridifyArgumentAdapter res = new GridifyArgumentAdapter();
 
         res.setTarget(arg.getTarget());
@@ -169,7 +169,7 @@ public final class GridifyArgumentBuilder {
         Object paramValue = GridifyUtils.collectionToParameter(paramCls, input);
 
         if (paramValue == null)
-            throw new GridException("Failed to create job argument for type: " + paramCls.getName());
+            throw new IgniteCheckedException("Failed to create job argument for type: " + paramCls.getName());
 
         mtdArgs[arg.getParamIndex()] = paramValue;
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/util/gridify/GridifyJobAdapter.java
----------------------------------------------------------------------
@@ -104,9 +104,9 @@ public final class GridifyArgumentBuilder {
      * @param input Input collection..
      * @return Argument for task.
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
@@ -144,9 +144,9 @@ public final class GridifyArgumentBuilder {
      * @param input Input collection used in job.
      * @return Argument for job.
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
diff --git a/modules/core/src/main/java/org/gridgain/grid/util/ipc/GridIpcEndpoint.java b/modules/core/src/main/java/org/gridgain/grid/util/ipc/GridIpcEndpoint.java
index c3f7d73..3f48ce1 100644
--- a/modules/core/src/main/java/org/gridgain/grid/util/ipc/GridIpcEndpoint.java
+++ b/modules/core/src/main/java/org/gridgain/grid/util/ipc/GridIpcEndpoint.java
@@ -9,7 +9,7 @@
 
 package org.gridgain.grid.util.ipc;
 
-import org.gridgain.grid.*;
+import org.apache.ignite.*;
 
 import java.io.*;
 
@@ -21,17 +21,17 @@ public interface GridIpcEndpoint extends Closeable {
      * Gets input stream associated with this IPC endpoint.
      *
      * @return IPC input stream.
      * @throws GridException If error occurred.
      */
-    public InputStream inputStream() throws GridException;
+    public InputStream inputStream() throws IgniteCheckedException;
 
     /**
      * Gets output stream associated with this IPC endpoint.
      *
      * @return IPC output stream.
      * @throws GridException If error occurred.
      */
-    public OutputStream outputStream() throws GridException;
+    public OutputStream outputStream() throws IgniteCheckedException;
 
     /**
      * Closes endpoint. Note that IPC endpoint may acquire native resources so it must be always closed

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/util/ipc/GridIpcEndpointBindException.java
----------------------------------------------------------------------
@@ -21,17 +21,17 @@ public interface GridIpcEndpoint extends Closeable {
      *
      * @return IPC input stream.
-     * @throws GridException If error occurred.
+     * @throws IgniteCheckedException If error occurred.
      */
@@ -21,17 +21,17 @@ public interface GridIpcEndpoint extends Closeable {
      *
      * @return IPC output stream.
-     * @throws GridException If error occurred.
+     * @throws IgniteCheckedException If error occurred.
      */
diff --git a/modules/core/src/main/java/org/gridgain/grid/util/ipc/GridIpcEndpointFactory.java b/modules/core/src/main/java/org/gridgain/grid/util/ipc/GridIpcEndpointFactory.java
index 4378f4a..8ede74b 100644
--- a/modules/core/src/main/java/org/gridgain/grid/util/ipc/GridIpcEndpointFactory.java
+++ b/modules/core/src/main/java/org/gridgain/grid/util/ipc/GridIpcEndpointFactory.java
@@ -25,9 +25,9 @@ public class GridIpcEndpointFactory {
      * @param endpointAddr Endpoint address.
      * @param log Log.
      * @return Connected client endpoint.
      * @throws GridException If failed to establish connection.
      */
-    public static GridIpcEndpoint connectEndpoint(String endpointAddr, IgniteLogger log) throws GridException {
+    public static GridIpcEndpoint connectEndpoint(String endpointAddr, IgniteLogger log) throws IgniteCheckedException {
         A.notNull(endpointAddr, "endpointAddr");
 
         String[] split = endpointAddr.split(":");
@@ -39,7 +39,7 @@ public class GridIpcEndpointFactory {
                 port = Integer.parseInt(split[1]);
             }
             catch (NumberFormatException e) {
-                throw new GridException("Failed to parse port number: " + endpointAddr, e);
+                throw new IgniteCheckedException("Failed to parse port number: " + endpointAddr, e);
             }
         }
         else
@@ -57,9 +57,9 @@ public class GridIpcEndpointFactory {
      * @param host Loopback host.
      * @param port Loopback endpoint port.
      * @return Connected client endpoint.
      * @throws GridException If connection failed.
      */
-    private static GridIpcEndpoint connectTcpEndpoint(String host, int port) throws GridException {
+    private static GridIpcEndpoint connectTcpEndpoint(String host, int port) throws IgniteCheckedException {
        return new GridIpcClientTcpEndpoint(host, port);
     }
 
@@ -69,9 +69,9 @@ public class GridIpcEndpointFactory {
      * @param port Endpoint port.
      * @param log Log.
      * @return Connected client endpoint.
      * @throws GridException If connection failed.
      */
-    private static GridIpcEndpoint connectSharedMemoryEndpoint(int port, IgniteLogger log) throws GridException {
+    private static GridIpcEndpoint connectSharedMemoryEndpoint(int port, IgniteLogger log) throws IgniteCheckedException {
         return new GridIpcSharedMemoryClientEndpoint(port, log);
     }
 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/util/ipc/GridIpcServerEndpoint.java
----------------------------------------------------------------------
@@ -25,9 +25,9 @@ public class GridIpcEndpointFactory {
      * @param log Log.
      * @return Connected client endpoint.
-     * @throws GridException If failed to establish connection.
+     * @throws IgniteCheckedException If failed to establish connection.
      */
@@ -57,9 +57,9 @@ public class GridIpcEndpointFactory {
      * @param port Loopback endpoint port.
      * @return Connected client endpoint.
-     * @throws GridException If connection failed.
+     * @throws IgniteCheckedException If connection failed.
      */
@@ -69,9 +69,9 @@ public class GridIpcEndpointFactory {
      * @param log Log.
      * @return Connected client endpoint.
-     * @throws GridException If connection failed.
+     * @throws IgniteCheckedException If connection failed.
      */
diff --git a/modules/core/src/main/java/org/gridgain/grid/util/ipc/GridIpcServerEndpoint.java b/modules/core/src/main/java/org/gridgain/grid/util/ipc/GridIpcServerEndpoint.java
index 0914d7b..8707c7e 100644
--- a/modules/core/src/main/java/org/gridgain/grid/util/ipc/GridIpcServerEndpoint.java
+++ b/modules/core/src/main/java/org/gridgain/grid/util/ipc/GridIpcServerEndpoint.java
@@ -9,7 +9,7 @@
 
 package org.gridgain.grid.util.ipc;
 
-import org.gridgain.grid.*;
+import org.apache.ignite.*;
 import org.jetbrains.annotations.*;
 
 import java.io.*;
@@ -23,16 +23,16 @@ public interface GridIpcServerEndpoint extends Closeable {
      * for IPC. This method will block until client connects to IPC server endpoint.
      *
      * @return Accepted client connection.
      * @throws GridException If accept failed and the endpoint is not usable anymore.
      */
-    public GridIpcEndpoint accept() throws GridException;
+    public GridIpcEndpoint accept() throws IgniteCheckedException;
 
     /**
      * Starts configured endpoint implementation.
      *
      * @throws GridException If failed to start server endpoint.
      */
-    public void start() throws GridException;
+    public void start() throws IgniteCheckedException;
 
     /**
      * Closes server IPC. After IPC is closed, no further operations can be performed on this

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/util/ipc/GridIpcServerEndpointDeserializer.java
----------------------------------------------------------------------
@@ -23,16 +23,16 @@ public interface GridIpcServerEndpoint extends Closeable {
      *
      * @return Accepted client connection.
-     * @throws GridException If accept failed and the endpoint is not usable anymore.
+     * @throws IgniteCheckedException If accept failed and the endpoint is not usable anymore.
      */
@@ -23,16 +23,16 @@ public interface GridIpcServerEndpoint extends Closeable {
      * Starts configured endpoint implementation.
      *
-     * @throws GridException If failed to start server endpoint.
+     * @throws IgniteCheckedException If failed to start server endpoint.
      */
diff --git a/modules/core/src/main/java/org/gridgain/grid/util/ipc/GridIpcServerEndpointDeserializer.java b/modules/core/src/main/java/org/gridgain/grid/util/ipc/GridIpcServerEndpointDeserializer.java
index 13b228d..88f104e 100644
--- a/modules/core/src/main/java/org/gridgain/grid/util/ipc/GridIpcServerEndpointDeserializer.java
+++ b/modules/core/src/main/java/org/gridgain/grid/util/ipc/GridIpcServerEndpointDeserializer.java
@@ -9,10 +9,10 @@
 
 package org.gridgain.grid.util.ipc;
 
-import org.gridgain.grid.*;
-import org.gridgain.grid.util.typedef.internal.*;
+import org.apache.ignite.*;
 import org.gridgain.grid.util.ipc.loopback.*;
 import org.gridgain.grid.util.ipc.shmem.*;
+import org.gridgain.grid.util.typedef.internal.*;
 
 import java.util.*;
 
@@ -26,15 +26,15 @@ public class GridIpcServerEndpointDeserializer {
      *
      * @param endpointCfg Map with properties of the IPC server endpoint config.
      * @return Deserialized instance of {@link GridIpcServerEndpoint}.
      * @throws GridException If any problem with configuration properties setting has happened.
      */
-    public static GridIpcServerEndpoint deserialize(Map<String,String> endpointCfg) throws GridException {
+    public static GridIpcServerEndpoint deserialize(Map<String,String> endpointCfg) throws IgniteCheckedException {
         A.notNull(endpointCfg, "endpointCfg");
 
         String endpointType = endpointCfg.get("type");
 
         if (endpointType == null)
-            throw new GridException("Failed to create server endpoint (type is not specified)");
+            throw new IgniteCheckedException("Failed to create server endpoint (type is not specified)");
 
         switch (endpointType) {
             case "shmem": {
@@ -52,7 +52,7 @@ public class GridIpcServerEndpointDeserializer {
                 return endpoint;
             }
             default:
-                throw new GridException("Failed to create server endpoint (type is unknown): " + endpointType);
+                throw new IgniteCheckedException("Failed to create server endpoint (type is unknown): " + endpointType);
         }
     }
 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/util/ipc/GridIpcToNioAdapter.java
----------------------------------------------------------------------
@@ -26,15 +26,15 @@ public class GridIpcServerEndpointDeserializer {
      * @param endpointCfg Map with properties of the IPC server endpoint config.
      * @return Deserialized instance of {@link GridIpcServerEndpoint}.
-     * @throws GridException If any problem with configuration properties setting has happened.
+     * @throws IgniteCheckedException If any problem with configuration properties setting has happened.
      */
diff --git a/modules/core/src/main/java/org/gridgain/grid/util/ipc/loopback/GridIpcClientTcpEndpoint.java b/modules/core/src/main/java/org/gridgain/grid/util/ipc/loopback/GridIpcClientTcpEndpoint.java
index 7ea6ab7..732ef15 100644
--- a/modules/core/src/main/java/org/gridgain/grid/util/ipc/loopback/GridIpcClientTcpEndpoint.java
+++ b/modules/core/src/main/java/org/gridgain/grid/util/ipc/loopback/GridIpcClientTcpEndpoint.java
@@ -9,9 +9,9 @@
 
 package org.gridgain.grid.util.ipc.loopback;
 
-import org.gridgain.grid.*;
-import org.gridgain.grid.util.typedef.internal.*;
+import org.apache.ignite.*;
 import org.gridgain.grid.util.ipc.*;
+import org.gridgain.grid.util.typedef.internal.*;
 
 import java.io.*;
 import java.net.*;
@@ -39,36 +39,36 @@ public class GridIpcClientTcpEndpoint implements GridIpcEndpoint {
      *
      * @param port Port.
      * @param host Host.
      * @throws GridException If connection fails.
      */
-    public GridIpcClientTcpEndpoint(String host, int port) throws GridException {
+    public GridIpcClientTcpEndpoint(String host, int port) throws IgniteCheckedException {
         clientSock = new Socket();
 
         try {
             clientSock.connect(new InetSocketAddress(host, port));
         }
         catch (IOException e) {
-            throw new GridException("Failed to connect to endpoint [host=" + host + ", port=" + port + ']', e);
+            throw new IgniteCheckedException("Failed to connect to endpoint [host=" + host + ", port=" + port + ']', e);
         }
     }
 
     /** {@inheritDoc} */
-    @Override public InputStream inputStream() throws GridException {
+    @Override public InputStream inputStream() throws IgniteCheckedException {
         try {
             return clientSock.getInputStream();
         }
         catch (IOException e) {
-            throw new GridException(e);
+            throw new IgniteCheckedException(e);
         }
     }
 
     /** {@inheritDoc} */
-    @Override public OutputStream outputStream() throws GridException {
+    @Override public OutputStream outputStream() throws IgniteCheckedException {
         try {
             return clientSock.getOutputStream();
         }
         catch (IOException e) {
-            throw new GridException(e);
+            throw new IgniteCheckedException(e);
         }
     }
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/util/ipc/loopback/GridIpcServerTcpEndpoint.java
----------------------------------------------------------------------
@@ -39,36 +39,36 @@ public class GridIpcClientTcpEndpoint implements GridIpcEndpoint {
      * @param port Port.
      * @param host Host.
-     * @throws GridException If connection fails.
+     * @throws IgniteCheckedException If connection fails.
      */
diff --git a/modules/core/src/main/java/org/gridgain/grid/util/ipc/loopback/GridIpcServerTcpEndpoint.java b/modules/core/src/main/java/org/gridgain/grid/util/ipc/loopback/GridIpcServerTcpEndpoint.java
index 699b033..fa016a5 100644
--- a/modules/core/src/main/java/org/gridgain/grid/util/ipc/loopback/GridIpcServerTcpEndpoint.java
+++ b/modules/core/src/main/java/org/gridgain/grid/util/ipc/loopback/GridIpcServerTcpEndpoint.java
@@ -43,7 +43,7 @@ public class GridIpcServerTcpEndpoint implements GridIpcServerEndpoint {
     private IgniteLogger log;
 
     /** {@inheritDoc} */
-    @Override public void start() throws GridException {
+    @Override public void start() throws IgniteCheckedException {
         if (port <= 0 || port >= 0xffff)
             throw new GridIpcEndpointBindException("Port value is illegal: " + port);
 
@@ -67,14 +67,14 @@ public class GridIpcServerTcpEndpoint implements GridIpcServerEndpoint {
     }
 
     /** {@inheritDoc} */
-    @Override public GridIpcEndpoint accept() throws GridException {
+    @Override public GridIpcEndpoint accept() throws IgniteCheckedException {
         try {
             Socket sock = srvSock.accept();
 
             return new GridIpcClientTcpEndpoint(sock);
         }
         catch (IOException e) {
-            throw new GridException(e);
+            throw new IgniteCheckedException(e);
         }
     }
 
@@ -134,9 +134,9 @@ public class GridIpcServerTcpEndpoint implements GridIpcServerEndpoint {
      * Sets configuration properties from the map.
      *
      * @param endpointCfg Map of properties.
      * @throws GridException If invalid property name or value.
      */
-    public void setupConfiguration(Map<String, String> endpointCfg) throws GridException {
+    public void setupConfiguration(Map<String, String> endpointCfg) throws IgniteCheckedException {
         for (Map.Entry<String,String> e : endpointCfg.entrySet()) {
             try {
                 switch (e.getKey()) {
@@ -157,14 +157,14 @@ public class GridIpcServerTcpEndpoint implements GridIpcServerEndpoint {
                         break;
 
                     default:
-                        throw new GridException("Invalid property '" + e.getKey() + "' of " + getClass().getSimpleName());
+                        throw new IgniteCheckedException("Invalid property '" + e.getKey() + "' of " + getClass().getSimpleName());
                 }
             }
             catch (Throwable t) {
-                if (t instanceof GridException)
+                if (t instanceof IgniteCheckedException)
                     throw t;
 
-                throw new GridException("Invalid value '" + e.getValue() + "' of the property '" + e.getKey() + "' in " +
+                throw new IgniteCheckedException("Invalid value '" + e.getValue() + "' of the property '" + e.getKey() + "' in " +
                     getClass().getSimpleName(), t);
             }
         }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/util/ipc/shmem/GridIpcOutOfSystemResourcesException.java
----------------------------------------------------------------------
@@ -134,9 +134,9 @@ public class GridIpcServerTcpEndpoint implements GridIpcServerEndpoint {
      *
      * @param endpointCfg Map of properties.
-     * @throws GridException If invalid property name or value.
+     * @throws IgniteCheckedException If invalid property name or value.
      */
diff --git a/modules/core/src/main/java/org/gridgain/grid/util/ipc/shmem/GridIpcSharedMemoryClientEndpoint.java b/modules/core/src/main/java/org/gridgain/grid/util/ipc/shmem/GridIpcSharedMemoryClientEndpoint.java
index cf96ed8..585099e 100644
--- a/modules/core/src/main/java/org/gridgain/grid/util/ipc/shmem/GridIpcSharedMemoryClientEndpoint.java
+++ b/modules/core/src/main/java/org/gridgain/grid/util/ipc/shmem/GridIpcSharedMemoryClientEndpoint.java
@@ -74,9 +74,9 @@ public class GridIpcSharedMemoryClientEndpoint implements GridIpcEndpoint {
      *
      * @param port Port server endpoint bound to.
      * @param parent Parent logger.
      * @throws GridException If connection fails.
      */
-    public GridIpcSharedMemoryClientEndpoint(int port, IgniteLogger parent) throws GridException {
+    public GridIpcSharedMemoryClientEndpoint(int port, IgniteLogger parent) throws IgniteCheckedException {
         this(port, 0, parent);
     }
 
@@ -87,10 +87,10 @@ public class GridIpcSharedMemoryClientEndpoint implements GridIpcEndpoint {
      * @param port Port server endpoint bound to.
      * @param timeout Connection timeout.
      * @param parent Parent logger.
      * @throws GridException If connection fails.
      */
     @SuppressWarnings({"CallToThreadStartDuringObjectConstruction", "ErrorNotRethrown"})
-    public GridIpcSharedMemoryClientEndpoint(int port, int timeout, IgniteLogger parent) throws GridException {
+    public GridIpcSharedMemoryClientEndpoint(int port, int timeout, IgniteLogger parent) throws IgniteCheckedException {
         assert port > 0;
         assert port < 0xffff;
 
@@ -149,11 +149,11 @@ public class GridIpcSharedMemoryClientEndpoint implements GridIpcEndpoint {
             throw GridIpcSharedMemoryUtils.linkError(e);
         }
         catch (IOException e) {
-            throw new GridException("Failed to connect shared memory endpoint to port " +
+            throw new IgniteCheckedException("Failed to connect shared memory endpoint to port " +
                 "(is shared memory server endpoint up and running?): " + port, e);
         }
         catch (ClassNotFoundException | ClassCastException e) {
-            throw new GridException(e);
+            throw new IgniteCheckedException(e);
         }
         finally {
             U.closeQuiet(sock);
@@ -168,7 +168,7 @@ public class GridIpcSharedMemoryClientEndpoint implements GridIpcEndpoint {
         }
 
         if (err != null) // Error response.
-            throw new GridException(err);
+            throw new IgniteCheckedException(err);
 
         this.inSpace = inSpace;
         this.outSpace = outSpace;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/util/ipc/shmem/GridIpcSharedMemoryInputStream.java
----------------------------------------------------------------------
@@ -74,9 +74,9 @@ public class GridIpcSharedMemoryClientEndpoint implements GridIpcEndpoint {
      * @param port Port server endpoint bound to.
      * @param parent Parent logger.
-     * @throws GridException If connection fails.
+     * @throws IgniteCheckedException If connection fails.
      */
@@ -87,10 +87,10 @@ public class GridIpcSharedMemoryClientEndpoint implements GridIpcEndpoint {
      * @param timeout Connection timeout.
      * @param parent Parent logger.
-     * @throws GridException If connection fails.
+     * @throws IgniteCheckedException If connection fails.
      */
     @SuppressWarnings({"CallToThreadStartDuringObjectConstruction", "ErrorNotRethrown"})
diff --git a/modules/core/src/main/java/org/gridgain/grid/util/ipc/shmem/GridIpcSharedMemoryNativeLoader.java b/modules/core/src/main/java/org/gridgain/grid/util/ipc/shmem/GridIpcSharedMemoryNativeLoader.java
index 536ba21..8790ca6 100644
--- a/modules/core/src/main/java/org/gridgain/grid/util/ipc/shmem/GridIpcSharedMemoryNativeLoader.java
+++ b/modules/core/src/main/java/org/gridgain/grid/util/ipc/shmem/GridIpcSharedMemoryNativeLoader.java
@@ -9,7 +9,7 @@
 
 package org.gridgain.grid.util.ipc.shmem;
 
-import org.gridgain.grid.*;
+import org.apache.ignite.*;
 import org.gridgain.grid.kernal.*;
 import org.gridgain.grid.util.typedef.internal.*;
 
@@ -77,9 +77,9 @@ public class GridIpcSharedMemoryNativeLoader {
     }
 
     /**
      * @throws GridException If failed.
      */
-    public static void load() throws GridException {
+    public static void load() throws IgniteCheckedException {
         if (loaded)
             return;
 
@@ -94,9 +94,9 @@ public class GridIpcSharedMemoryNativeLoader {
     }
 
     /**
      * @throws GridException If failed.
      */
-    private static void doLoad() throws GridException {
+    private static void doLoad() throws IgniteCheckedException {
         assert Thread.holdsLock(GridIpcSharedMemoryNativeLoader.class);
 
         Collection<Throwable> errs = new LinkedList<>();
@@ -127,10 +127,10 @@ public class GridIpcSharedMemoryNativeLoader {
             // Failed to find the library.
             assert !errs.isEmpty();
 
-            throw new GridException("Failed to load native IPC library: " + errs);
+            throw new IgniteCheckedException("Failed to load native IPC library: " + errs);
         }
         catch (IOException e) {
-            throw new GridException("Failed to obtain file lock: " + LOCK_FILE, e);
+            throw new IgniteCheckedException("Failed to obtain file lock: " + LOCK_FILE, e);
         }
     }
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/util/ipc/shmem/GridIpcSharedMemoryOperationTimedoutException.java
----------------------------------------------------------------------
@@ -77,9 +77,9 @@ public class GridIpcSharedMemoryNativeLoader {
 
     /**
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
@@ -94,9 +94,9 @@ public class GridIpcSharedMemoryNativeLoader {
 
     /**
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */